@@ -217,14 +217,21 @@ class CommandsCache(cabc.Mapping):
         """Predicts whether a command list is able to be run on a background
         thread, rather than the main thread.
         """
-        name = self.cached_name(cmd[0])
+        predictor = self.get_predictor_threadable(cmd[0])
+        return predictor(cmd[1:])
+
+    def get_predictor_threadable(self, cmd0):
+        """Return the predictor whether a command list is able to be run on a
+        background thread, rather than the main thread.
+        """
+        name = self.cached_name(cmd0)
         predictors = self.threadable_predictors
         if ON_WINDOWS:
             # On all names (keys) are stored in upper case so instead
             # we get the original cmd or alias name
             path, _ = self.lazyget(name, (None, None))
             if path is None:
-                return True
+                return predict_true
             else:
                 name = pathbasename(path)
             if name not in predictors:
@@ -232,15 +239,26 @@ class CommandsCache(cabc.Mapping):
                 if pre in predictors:
                     predictors[name] = predictors[pre]
         if name not in predictors:
-            predictors[name] = self.default_predictor(name, cmd[0])
+            predictors[name] = self.default_predictor(name, cmd0)
         predictor = predictors[name]
-        return predictor(cmd[1:])
+        return predictor
 
     #
     # Background Predictors (as methods)
     #
 
     def default_predictor(self, name, cmd0):
+        """Default predictor, using predictor from original command if the
+        command is an alias, elseif build a predictor based on binary analysis
+        on POSIX, else return predict_true.
+        """
+        # alias stuff
+        if not os.path.isabs(cmd0) and os.sep not in cmd0:
+            alss = getattr(builtins, "aliases", dict())
+            if cmd0 in alss:
+                return self.default_predictor_alias(cmd0)
+
+        # other default stuff
         if ON_POSIX:
             return self.default_predictor_readbin(
                 name, cmd0, timeout=0.1, failure=predict_true
@@ -248,6 +266,30 @@ class CommandsCache(cabc.Mapping):
         else:
             return predict_true
 
+    def default_predictor_alias(self, cmd0):
+        alias_recursion_limit = (
+            10
+        )  # this limit is se to handle infinite loops in aliases definition
+        first_args = []  # contains in reverse order args passed to the aliased command
+        alss = getattr(builtins, "aliases", dict())
+        while cmd0 in alss:
+            alias_name = alss[cmd0]
+            if isinstance(alias_name, (str, bytes)) or not isinstance(
+                alias_name, cabc.Sequence
+            ):
+                return predict_true
+            for arg in alias_name[:0:-1]:
+                first_args.insert(0, arg)
+            if cmd0 == alias_name[0]:
+                # it is a self-alias stop recursion immediatly
+                return predict_true
+            cmd0 = alias_name[0]
+            alias_recursion_limit -= 1
+            if alias_recursion_limit == 0:
+                return predict_true
+        predictor_cmd0 = self.get_predictor_threadable(cmd0)
+        return lambda cmd1: predictor_cmd0(first_args[::-1] + cmd1)
+
     def default_predictor_readbin(self, name, cmd0, timeout, failure):
         """Make a default predictor by
         analyzing the content of the binary. Should only works on POSIX.
@@ -338,9 +380,9 @@ def predict_shell(args):
 @lazyobject
 def HELP_VER_PREDICTOR_PARSER():
     p = argparse.ArgumentParser("cmd", add_help=False)
-    p.add_argument("-h", "--help", dest="help", action="store_true", default=None)
+    p.add_argument("-h", "--help", dest="help", nargs="?", action="store", default=None)
     p.add_argument(
-        "-v", "-V", "--version", dest="version", action="store_true", default=None
+        "-v", "-V", "--version", dest="version", nargs="?", action="store", default=None
     )
     return p
 
@@ -380,24 +422,43 @@ def predict_hg(args):
         return not ns.interactive
 
 
+def predict_env(args):
+    """Predict if env is launching a threadable command or not.
+    The launched command is extracted from env args, and the predictor of
+    lauched command is used."""
+
+    for i in range(len(args)):
+        if args[i] and args[i][0] != "-" and "=" not in args[i]:
+            # args[i] is the command and the following is its arguments
+            # so args[i:] is used to predict if the command is threadable
+            return builtins.__xonsh__.commands_cache.predict_threadable(args[i:])
+    return True
+
+
 def default_threadable_predictors():
     """Generates a new defaultdict for known threadable predictors.
     The default is to predict true.
     """
     # alphabetical, for what it is worth.
     predictors = {
-        "aurman": predict_false,
         "asciinema": predict_help_ver,
+        "aurman": predict_false,
+        "awk": predict_true,
         "bash": predict_shell,
-        "csh": predict_shell,
+        "cat": predict_false,
         "clear": predict_false,
         "cls": predict_false,
         "cmd": predict_shell,
         "cryptop": predict_false,
+        "cryptsetup": predict_true,
+        "csh": predict_shell,
         "curl": predict_true,
-        "ex": predict_false,
         "emacsclient": predict_false,
+        "env": predict_env,
+        "ex": predict_false,
         "fish": predict_shell,
+        "gawk": predict_true,
+        "git": predict_true,
         "gvim": predict_help_ver,
         "hg": predict_hg,
         "htop": predict_help_ver,
@@ -406,38 +467,52 @@ def default_threadable_predictors():
         "less": predict_help_ver,
         "ls": predict_true,
         "man": predict_help_ver,
+        "mc": predict_false,
         "more": predict_help_ver,
-        "mvim": predict_help_ver,
         "mutt": predict_help_ver,
+        "mvim": predict_help_ver,
         "nano": predict_help_ver,
+        "nmcli": predict_true,
         "nvim": predict_false,
+        "percol": predict_false,
         "ponysay": predict_help_ver,
         "psql": predict_false,
+        "push": predict_shell,
+        "pv": predict_false,
         "python": predict_shell,
         "python2": predict_shell,
         "python3": predict_shell,
-        "repo": predict_help_ver,
         "ranger": predict_help_ver,
+        "repo": predict_help_ver,
         "rview": predict_false,
         "rvim": predict_false,
+        "rwt": predict_shell,
         "scp": predict_false,
         "sh": predict_shell,
         "ssh": predict_false,
         "startx": predict_false,
         "sudo": predict_help_ver,
+        "sudoedit": predict_help_ver,
+        "systemctl": predict_true,
         "tcsh": predict_shell,
         "telnet": predict_false,
-        "tput": predict_false,
         "top": predict_help_ver,
+        "tput": predict_false,
+        "udisksctl": predict_true,
+        "unzip": predict_true,
         "vi": predict_false,
         "view": predict_false,
         "vim": predict_false,
         "vimpager": predict_help_ver,
         "weechat": predict_help_ver,
+        "wget": predict_true,
         "xclip": predict_help_ver,
         "xo": predict_help_ver,
-        "xonsh": predict_shell,
         "xon.sh": predict_shell,
+        "xonsh": predict_shell,
+        "yes": predict_false,
+        "zip": predict_true,
+        "zipinfo": predict_true,
         "zsh": predict_shell,
     }
     return predictors
