@@ -59,7 +59,6 @@ from xonsh.tools import (
     bool_seq_to_csv,
     DefaultNotGiven,
     print_exception,
-    setup_win_unicode_console,
     intensify_colors_on_win_setter,
     is_dynamic_cwd_width,
     to_dynamic_cwd_tuple,
@@ -184,7 +183,8 @@ def to_debug(x):
 
 class LsColors(cabc.MutableMapping):
     """Helps convert to/from $LS_COLORS format, respecting the xonsh color style.
-    This accepts the same inputs as dict().
+    This accepts the same inputs as dict(). The link ``target`` is represented
+    by the special ``"TARGET"`` color.
     """
 
     default_settings = {
@@ -368,7 +368,12 @@ class LsColors(cabc.MutableMapping):
                     key
                     + "="
                     + ";".join(
-                        [ansi_color_name_to_escape_code(v, cmap=style) for v in val]
+                        [
+                            "target"
+                            if v == "TARGET"
+                            else ansi_color_name_to_escape_code(v, cmap=style)
+                            for v in val
+                        ]
                     )
                     for key, val in sorted(self._d.items())
                 ]
@@ -408,10 +413,17 @@ class LsColors(cabc.MutableMapping):
             key, eq, esc = item.partition("=")
             if not eq:
                 # not a valid item
-                continue
-            data[key] = ansi_color_escape_code_to_name(
-                esc, "default", reversed_style=reversed_default
-            )
+                pass
+            elif esc == "target":
+                data[key] = ("TARGET",)
+            else:
+                try:
+                    data[key] = ansi_color_escape_code_to_name(
+                        esc, "default", reversed_style=reversed_default
+                    )
+                except Exception as e:
+                    print("xonsh:warning:" + str(e), file=sys.stderr)
+                    data[key] = ("NO_COLOR",)
         obj._d = data
         return obj
 
@@ -545,6 +557,7 @@ def DEFAULT_ENSURERS():
         "PRETTY_PRINT_RESULTS": (is_bool, to_bool, bool_to_str),
         "PROMPT": (is_string_or_callable, ensure_string, ensure_string),
         "PROMPT_FIELDS": (always_true, None, None),
+        "PROMPT_REFRESH_INTERVAL": (is_float, float, str),
         "PROMPT_TOOLKIT_COLOR_DEPTH": (
             always_false,
             ptk2_color_depth_setter,
@@ -568,7 +581,6 @@ def DEFAULT_ENSURERS():
         "VC_HG_SHOW_BRANCH": (is_bool, to_bool, bool_to_str),
         "VI_MODE": (is_bool, to_bool, bool_to_str),
         "VIRTUAL_ENV": (is_string, ensure_string, ensure_string),
-        "WIN_UNICODE_CONSOLE": (always_false, setup_win_unicode_console, bool_to_str),
         "XONSHRC": (is_env_path, str_to_env_path, env_path_to_str),
         "XONSH_APPEND_NEWLINE": (is_bool, to_bool, bool_to_str),
         "XONSH_AUTOPAIR": (is_bool, to_bool, bool_to_str),
@@ -731,6 +743,7 @@ def DEFAULT_VALUES():
         "PATHEXT": [".COM", ".EXE", ".BAT", ".CMD"] if ON_WINDOWS else [],
         "PRETTY_PRINT_RESULTS": True,
         "PROMPT": prompt.default_prompt(),
+        "PROMPT_REFRESH_INTERVAL": 0,
         "PROMPT_TOOLKIT_COLOR_DEPTH": "",
         "PTK_STYLE_OVERRIDES": dict(PTK2_STYLE),
         "PUSHD_MINUS": False,
@@ -751,7 +764,6 @@ def DEFAULT_VALUES():
         "VC_BRANCH_TIMEOUT": 0.2 if ON_WINDOWS else 0.1,
         "VC_HG_SHOW_BRANCH": True,
         "VI_MODE": False,
-        "WIN_UNICODE_CONSOLE": True,
         "XDG_CONFIG_HOME": os.path.expanduser(os.path.join("~", ".config")),
         "XDG_DATA_HOME": os.path.expanduser(os.path.join("~", ".local", "share")),
         "XONSHRC": default_xonshrc,
@@ -874,15 +886,15 @@ def DEFAULT_DOCS():
             "completions, auto-suggestions, etc.\n\nChanging it at runtime will "
             "take immediate effect, so you can quickly disable and enable "
             "completions during shell sessions.\n\n"
-            "- If ``$COMPLETIONS_DISPLAY`` is ``none`` or ``false``, do not display\n"
-            "  those completions.\n"
+            "- If ``$COMPLETIONS_DISPLAY`` is ``none`` or ``false``, do not display"
+            " those completions.\n"
             "- If ``$COMPLETIONS_DISPLAY`` is ``single``, display completions in a\n"
             "  single column while typing.\n"
-            "- If ``$COMPLETIONS_DISPLAY`` is ``multi`` or ``true``, display completions\n"
-            "  in multiple columns while typing.\n\n"
+            "- If ``$COMPLETIONS_DISPLAY`` is ``multi`` or ``true``, display completions"
+            " in multiple columns while typing.\n\n"
             "- If ``$COMPLETIONS_DISPLAY`` is ``readline``, display completions\n"
             "  will emulate the behavior of readline.\n\n"
-            "These option values are not case- or type-sensitive, so e.g."
+            "These option values are not case- or type-sensitive, so e.g. "
             "writing ``$COMPLETIONS_DISPLAY = None`` "
             "and ``$COMPLETIONS_DISPLAY = 'none'`` are equivalent. Only usable with "
             "``$SHELL_TYPE=prompt_toolkit``"
@@ -902,9 +914,9 @@ def DEFAULT_DOCS():
             "for confirmation."
         ),
         "COMPLETION_IN_THREAD": VarDocs(
-            "When generating the completions takes a lot of time, "
-            "it’s better to do this in a background thed."
-            "When this is True, background theads is used for completion."
+            "When generating the completions takes time, "
+            "it’s better to do this in a background thread. "
+            "When this is True, background threads is used for completion."
         ),
         "DIRSTACK_SIZE": VarDocs("Maximum size of the directory stack."),
         "DOTGLOB": VarDocs(
@@ -1059,6 +1071,11 @@ def DEFAULT_DOCS():
             "This value is never inherited from parent processes.",
             default="``xonsh.environ.DEFAULT_PROMPT``",
         ),
+        "PROMPT_REFRESH_INTERVAL": VarDocs(
+            "Evaluate $PROMPT, $RIGHT_PROMPT and $BOTTOM_TOOLBAR every so many seconds."
+            "This param default is zero."
+            "And if using this param, $UPDATE_COMPLETIONS_ON_KEYPRESS must be True."
+        ),
         "PROMPT_TOOLKIT_COLOR_DEPTH": VarDocs(
             "The color depth used by prompt toolkit 2. Possible values are: "
             "``DEPTH_1_BIT``, ``DEPTH_4_BIT``, ``DEPTH_8_BIT``, ``DEPTH_24_BIT`` "
@@ -1178,11 +1195,6 @@ def DEFAULT_DOCS():
         "VIRTUAL_ENV": VarDocs(
             "Path to the currently active Python environment.", configurable=False
         ),
-        "WIN_UNICODE_CONSOLE": VarDocs(
-            "Enables unicode support in windows terminals. Requires the external "
-            "library ``win_unicode_console``.",
-            configurable=ON_WINDOWS,
-        ),
         "XDG_CONFIG_HOME": VarDocs(
             "Open desktop standard configuration home dir. This is the same "
             "default as used in the standard.",
@@ -1348,8 +1360,8 @@ def DEFAULT_DOCS():
             "Logging to a file is not enabled by default."
         ),
         "XONSH_DATETIME_FORMAT": VarDocs(
-            "The format that is used for ``datetime.strptime()`` in various places"
-            "i.e the history timestamp option"
+            "The format that is used for ``datetime.strptime()`` in various places, "
+            "i.e the history timestamp option."
         ),
     }
 
