@@ -62,12 +62,16 @@ ON_NETBSD = LazyBool(
     lambda: (sys.platform.startswith("netbsd")), globals(), "ON_NETBSD"
 )
 """``True`` if on a NetBSD operating system, else ``False``."""
+ON_OPENBSD = LazyBool(
+    lambda: (sys.platform.startswith("openbsd")), globals(), "ON_OPENBSD"
+)
+"""``True`` if on a OpenBSD operating system, else ``False``."""
 
 
 @lazybool
 def ON_BSD():
     """``True`` if on a BSD operating system, else ``False``."""
-    return bool(ON_FREEBSD) or bool(ON_NETBSD) or bool(ON_DRAGONFLY)
+    return bool(ON_FREEBSD) or bool(ON_NETBSD) or bool(ON_OPENBSD) or bool(ON_DRAGONFLY)
 
 
 @lazybool
@@ -76,6 +80,12 @@ def ON_BEOS():
     return sys.platform == "beos5" or sys.platform == "haiku1"
 
 
+@lazybool
+def ON_WSL():
+    """True if we are on Windows Subsystem for Linux (WSL)"""
+    return "Microsoft" in platform.release()
+
+
 #
 # Python & packages
 #
@@ -91,7 +101,7 @@ def PYTHON_VERSION_INFO_BYTES():
 
 
 ON_ANACONDA = LazyBool(
-    lambda: any(s in sys.version for s in {"Anaconda", "Continuum", "conda-forge"}),
+    lambda: pathlib.Path(sys.prefix).joinpath("conda-meta").exists(),
     globals(),
     "ON_ANACONDA",
 )
@@ -194,7 +204,9 @@ def ptk_below_max_supported():
 
 @functools.lru_cache(1)
 def best_shell_type():
-    if ON_WINDOWS or has_prompt_toolkit():
+    if builtins.__xonsh__.env.get("TERM", "") == "dumb":
+        return "dumb"
+    elif ON_WINDOWS or has_prompt_toolkit():
         return "prompt_toolkit"
     else:
         return "readline"
